==> qore-0.9.10.tar.bz2: qore-0.9.10/docs/modules/WebSocketClient/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore WebSocketClient Module Reference", "index.html", [
    [ "WebSocketClient Module", "index.html", [
      [ "Introduction to the WebSocketClient Module", "index.html#websocketclientintro", null ],
      [ "WebSocketClient Module Release History", "index.html#websocketclient_relnotes", [
        [ "v1.9.1", "index.html#wsc_v1_9_1", null ],
        [ "v1.9", "index.html#wsc_v1_9", null ],
        [ "v1.8", "index.html#wsc_v1_8", null ],
        [ "v1.7", "index.html#wsc_v1_7", null ],
        [ "v1.6.3", "index.html#wsc_v1_6_3", null ],
        [ "v1.6.2", "index.html#wsc_v1_6_2", null ],
        [ "v1.6.1", "index.html#wsc_v1_6_1", null ],
        [ "v1.6", "index.html#wsc_v1_6", null ],
        [ "v1.5", "index.html#wsc_v1_5", null ],
        [ "v1.4", "index.html#wsc_v1_4", null ],
        [ "v1.3", "index.html#wsc_v1_3", null ],
        [ "v1.2", "index.html#wsc_v1_2", null ],
        [ "v1.1", "index.html#wsc_v1_1", null ],
        [ "v1.0", "index.html#wsc_v1_0", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__date__and__time__functions.html#gab342176f1a1c5ac93fbf18faeda3e943",
"group__file__stat__constants.html#ga17069d0ba50fdbb0ab3c0b80d324cc6d",
"group__misc__functions.html#ga54e6ccaa8fdaa3213ae5550aa66629c9",
"group__regex__constants.html#gaa5ae5ce8410a6a2a4970fc1b21e06382",
"group__tattr__local__mode__constants.html#gaee28cceae79349ff888ba64408473382"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-0.9.11.tar.bz2: qore-0.9.11/docs/modules/WebSocketClient/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore WebSocketClient Module Reference", "index.html", [
    [ "WebSocketClient Module", "index.html", [
      [ "Introduction to the WebSocketClient Module", "index.html#websocketclientintro", null ],
      [ "WebSocketClient Module Release History", "index.html#websocketclient_relnotes", [
        [ "v1.9.1", "index.html#wsc_v1_9_1", null ],
        [ "v1.9", "index.html#wsc_v1_9", null ],
        [ "v1.8", "index.html#wsc_v1_8", null ],
        [ "v1.7", "index.html#wsc_v1_7", null ],
        [ "v1.6.3", "index.html#wsc_v1_6_3", null ],
        [ "v1.6.2", "index.html#wsc_v1_6_2", null ],
        [ "v1.6.1", "index.html#wsc_v1_6_1", null ],
        [ "v1.6", "index.html#wsc_v1_6", null ],
        [ "v1.5", "index.html#wsc_v1_5", null ],
        [ "v1.4", "index.html#wsc_v1_4", null ],
        [ "v1.3", "index.html#wsc_v1_3", null ],
        [ "v1.2", "index.html#wsc_v1_2", null ],
        [ "v1.1", "index.html#wsc_v1_1", null ],
        [ "v1.0", "index.html#wsc_v1_0", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__date__and__time__functions.html#gab342176f1a1c5ac93fbf18faeda3e943",
"group__file__stat__constants.html#ga0e71d3a1ee084309a8718f18d3dc95dc",
"group__misc__functions.html#ga3a1dcf3c8f3908896ca2aabfcc41010c",
"group__parse__options.html#gad9c582e8e0ece9d44ceeafa778ac12f1",
"group__tattr__input__mode__constants.html#ga33699e7ced48aa5f9512c068cc02c708"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
